ImmutableSlice

Struct ImmutableSlice 

pub struct ImmutableSlice<'k, K> { /* private fields */ }
Implements KeySet that use immutable slice.

It does not use any index for pointing remain keys. That is why it is recommended to use it with CachedKeySet.

Implementations

Source

impl<'k, K: Sync> ImmutableSlice<'k, K>

pub fn new(slice: &'k [K]) -> Self

pub fn cached( slice: &[K], clone_threshold: usize, ) -> CachedKeySet<K, ImmutableSlice<'_, K>>