pub struct SliceSourceWithRefs<'k, K, I: RefsIndex = u8> { /* private fields */ }Expand description
KeySet implementation that stores reference to slice with keys,
and indices of this slice that points retained keys.
Indices are stored partitioned to segments and stored as 8 (if I=u8) or 16-bit (if I=u16) integers.
Each segment covers $2^8$ or $2^{16}$ consecutive keys.
Empty segments are not stored.
Implementations