GOConf

Struct GOConf 

pub struct GOConf<GS: GroupSize = TwoToPowerBitsStatic<4>, SS: SeedSize = TwoToPowerBitsStatic<2>, S = BuildDefaultSeededHasher> {
    pub hash_builder: S,
    pub bits_per_seed: SS,
    pub bits_per_group: GS,
}
Configuration of family of (group-optimized) hash functions used by GOFunction and accepted by GOBuildConf constructors.

Good configurations can be obtained by calling one of the following functions: default_biggest, default_bigger, default, default_smallest. These functions are listed in order of increasing performance (in terms of size and evaluation speed) and time to construct the minimum perfect hash function. More details are included in their documentation and the paper: P. Beling, Fingerprinting-based minimal perfect hashing revisited, ACM Journal of Experimental Algorithmics, 2023, https://doi.org/10.1145/3596453

Fields

hash_builder: S

The family of hash functions used by the constructed GOFunction. (default: BuildDefaultSeededHasher)

bits_per_seed: SS

Size of seeds (in bits). (default: 4)

bits_per_group: GS

Size of groups (in bits). (default: 16)

Implementations

Source

impl GOConf<TwoToPowerBitsStatic<3>, TwoToPowerBitsStatic<0>, BuildDefaultSeededHasher>

pub fn default_biggest() -> Self

Creates a configuration in which the seed and group sizes are 1 and 8 bits respectively, which (when relative level size is 100) leads to a minimum perfect hash function whose:

  • size is about 2.52 bits per input key,
  • the expected number of levels visited during the evaluation is about 2.18,
  • construction takes about 4 times less time compared to the default configuration.
Source

impl GOConf<TwoToPowerBitsStatic<4>, TwoToPowerBitsStatic<1>, BuildDefaultSeededHasher>

pub fn default_bigger() -> Self

Creates a configuration in which the seed and group sizes are 2 and 16 bits respectively, which (when relative level size is 100) leads to a minimum perfect hash function whose:

  • size is about 2.36 bits per input key,
  • the expected number of levels visited during the evaluation is about 2.04,
  • construction takes about 3 times less time compared to the default configuration.
Source

impl GOConf<TwoToPowerBitsStatic<5>, Bits8, BuildDefaultSeededHasher>

pub fn default_smallest() -> Self

Creates a configuration in which the seed and group sizes are 8 and 32 bits respectively, which (when relative level size is 100) leads to a minimum perfect hash function whose:

  • size is about 2.10 bits per input key,
  • the expected number of levels visited during the evaluation is about 1.64,
  • construction takes about 13 times longer compared to the default configuration.
Source

impl<GS: GroupSize, SS: SeedSize> GOConf<GS, SS>

pub fn bps_bpg(bits_per_seed: SS, bits_per_group: GS) -> Self

Returns a configuration that uses seeds and groups of the sizes given in bits.

Source

impl<GS: GroupSize, SS: SeedSize, S: BuildSeededHasher> GOConf<GS, SS, S>

pub fn validate(&self)

Panics if the configuration is incorrect.

pub fn hash_bps_bpg( hash_builder: S, bits_per_seed: SS, bits_per_group: GS, ) -> Self

Returns a configuration that uses given family of hash functions and seeds and groups of the sizes given in bits.

pub fn hash_index<GetGroupSeed>( &self, hash: u64, level_size_groups: usize, group_seed: GetGroupSeed, ) -> usize
where GetGroupSeed: FnOnce(usize) -> u16,

Returns array index for given hash of key, size of level in groups, and group seed provided by group_seed.

pub fn key_index<GetGroupSeed, K>( &self, key: &K, level_seed: u64, level_size_groups: usize, group_seed: GetGroupSeed, ) -> usize
where GetGroupSeed: FnOnce(usize) -> u16, K: Hash,

Returns array index for given key, seed and size (in groups) of level, and group seed provided by group_seed.