pub struct CompactFast {
pub items: Box<[u8]>,
pub item_size: u8,
}Expand description
Implementation of CompressedArray that stores each value with the same number of bits required to store the largest one.
It uses unaligned memory reading and writing.
Fields
items: Box<[u8]>item_size: u8Trait Implementations
Sourceimpl CompressedArray for CompactFast
impl CompressedArray for CompactFast
Sourcefn write_bytes(&self) -> usize
fn write_bytes(&self) -> usize
Returns number of bytes which
write will write.Sourceconst MAX_FOR_UNUSED: bool = false
const MAX_FOR_UNUSED: bool = false
Expect
values to have usize::MAX for unused values; false if values must be sorted.Sourceimpl GetSize for CompactFast
impl GetSize for CompactFast
Sourceconst USES_DYN_MEM: bool = true
const USES_DYN_MEM: bool = true
true if and only if the variables of this type can use dynamic (heap) memory.Sourcefn size_bytes_dyn(&self) -> usize
fn size_bytes_dyn(&self) -> usize
Returns approximate number of bytes occupied by dynamic (heap) part of
self.
Same as self.size_bytes() - std::mem::size_of_val(self).Sourcefn size_bytes_content_dyn(&self) -> usize
fn size_bytes_content_dyn(&self) -> usize
Returns approximate number of bytes occupied by dynamic (heap) part of
self content.
It usually equals to size_bytes_dyn().
However, sometimes it is smaller by the amount of memory reserved but not yet used
(e.g., size_bytes_content_dyn() only takes into account the length of the vector and not its capacity).Sourcefn size_bytes(&self) -> usize
fn size_bytes(&self) -> usize
Returns approximate, total (including heap memory) number of bytes occupied by
self.Auto Trait Implementations
impl Freeze for CompactFast
impl RefUnwindSafe for CompactFast
impl Send for CompactFast
impl Sync for CompactFast
impl Unpin for CompactFast
impl UnsafeUnpin for CompactFast
impl UnwindSafe for CompactFast