pub struct LinearRegressionArray<C> { /* private fields */ }Expand description
Implementation of CompressedArray that stores differences of values and linear regression
with the same number of bits required to store the largest difference.