Function

Struct Function 

pub struct Function<SS, SC = SeedOnly, CA = DefaultCompressedArray, S = BuildDefaultSeededHasher>
where SS: SeedSize,
{ /* private fields */ }
PHast (Perfect Hashing made fast) - Minimal Perfect Hash Function with very fast evaluation and size below 2 bits/key developed by Piotr Beling and Peter Sanders.

It can be used with the following SeedChooser (which specify a particular PHast variant): [ShiftOnlyWrapped] (PHast+ with wrapping), [ShiftSeedWrapped] (PHast/PHast+ hybrid), SeedOnly (regular PHast).

Note that some SeedChoosers can be used only with Function2.

See: Piotr Beling, Peter Sanders, PHast - Perfect Hashing made fast, 2025, https://arxiv.org/abs/2504.17918

Implementations

Source

impl<SS: SeedSize, SC: SeedChooser, CA: CompressedArray, S: BuildSeededHasher> Function<SS, SC, CA, S>

pub fn get<K>(&self, key: &K) -> usize
where K: Hash + ?Sized,

Returns value assigned to the given key.

The returned value is in the range from 0 (inclusive) to the number of elements in the input key collection (exclusive). key should come from the input key collection given during construction. For keys not in the collection, returns usize::MAX.

pub fn with_vec_p_hash_sc<K>( keys: Vec<K>, params: &Params<SS>, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash,

Constructs Function for given keys, using a single thread and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn with_vec_p_threads_hash_sc<K>( keys: Vec<K>, params: &Params<SS>, threads_num: usize, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash + Sync + Send, S: Sync, SC: Sync,

Constructs Function for given keys, using multiple (given number of) threads and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn with_slice_p_hash_sc<K>( keys: &[K], params: &Params<SS>, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash + Clone,

Constructs Function for given keys, using a single thread and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn with_slice_p_threads_hash_sc<K>( keys: &[K], params: &Params<SS>, threads_num: usize, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash + Sync + Send + Clone, S: Sync, SC: Sync,

Constructs Function for given keys, using multiple (given number of) threads and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn minimal_output_range(&self, num_of_keys: usize) -> usize

Returns output range of minimal (perfect or k-perfect) function for given number of keys, i.e. 1 + maximum value that minimal function can return.

pub fn output_range(&self) -> usize

Returns output range of self, i.e. 1 + maximum value that self can return.

pub fn write_bytes(&self) -> usize

Returns number of bytes which write will write.

pub fn write(&self, output: &mut dyn Write) -> Result<()>

Writes self to the output.

pub fn read_with_hasher_sc( input: &mut dyn Read, hasher: S, seed_chooser: SC, ) -> Result<Self>

Read Self from the input. hasher and seed_chooser must be the same as used by the structure written.

Source

impl<SS: SeedSize> Function<SS, SeedOnly, DefaultCompressedArray, BuildDefaultSeededHasher>

pub fn read(input: &mut dyn Read) -> Result<Self>

Read Self from the input. Uses default hasher and seed chooser.

Source

impl Function<Bits8, SeedOnly, DefaultCompressedArray, BuildDefaultSeededHasher>

pub fn from_vec_st<K>(keys: Vec<K>) -> Self
where K: Hash,

Constructs Function for given keys, using a single thread.

keys cannot contain duplicates.

pub fn from_vec_mt<K>(keys: Vec<K>) -> Self
where K: Hash + Send + Sync,

Constructs Function for given keys, using multiple threads.

keys cannot contain duplicates.

pub fn from_slice_st<K>(keys: &[K]) -> Self
where K: Hash + Clone,

Constructs Function for given keys, using a single thread.

keys cannot contain duplicates.

pub fn from_slice_mt<K>(keys: &[K]) -> Self
where K: Hash + Clone + Send + Sync,

Constructs Function for given keys, using multiple threads.

keys cannot contain duplicates.