Perfect

Struct Perfect 

pub struct Perfect<SS: SeedSize, SC = SeedOnly, S = BuildDefaultSeededHasher> { /* private fields */ }
PHast (Perfect Hashing made fast) - (K-)Perfect (not necessary minimal) Hash Function with very fast evaluation developed by Piotr Beling and Peter Sanders. Experimental.

Can be used with the following seed choosers (which specify a particular PHast variant): [ShiftOnlyWrapped], [ShiftSeedWrapped], SeedOnly, SeedOnlyK.

See: Piotr Beling, Peter Sanders, PHast - Perfect Hashing made fast, 2025, https://arxiv.org/abs/2504.17918

Implementations

Source

impl<SS: SeedSize, SC: SeedChooser, S: BuildSeededHasher> Perfect<SS, SC, S>

pub fn get<K>(&self, key: &K) -> usize
where K: Hash + ?Sized,

Returns value assigned to the given key.

The returned value is in the range from 0 (inclusive) to the number of elements in the input key collection (exclusive). key must come from the input key collection given during construction.

pub fn with_vec_p_hash_sc<K>( keys: Vec<K>, params: &Params<SS>, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash,

Constructs Perfect function for given keys, using a single thread and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn with_vec_p_threads_hash_sc<K>( keys: Vec<K>, params: &Params<SS>, threads_num: usize, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash + Sync + Send, S: Sync, SC: Sync,

Constructs Perfect function for given keys, using multiple (given number of) threads and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn with_slice_p_hash_sc<K>( keys: &[K], params: &Params<SS>, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash + Clone,

Constructs Perfect function for given keys, using a single thread and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn with_slice_p_threads_hash_sc<K>( keys: &[K], params: &Params<SS>, threads_num: usize, hasher: S, seed_chooser: SC, ) -> Self
where K: Hash + Sync + Send + Clone, S: Sync, SC: Sync,

Constructs Perfect function for given keys, using multiple (given number of) threads and given parameters: number of bits per seed, average bucket size (equals bucket_size100/100.0) and hasher.

bits_per_seed_to_100_bucket_size can be used to calculate good bucket_size100. keys cannot contain duplicates.

pub fn k(&self) -> u8

Returns maximum number of keys which can be mapped to the same value by k-Perfect function self.

pub fn minimal_output_range(&self, num_of_keys: usize) -> usize

Returns output range of minimal (perfect or k-perfect) function for given number of keys, i.e. 1 + maximum value that minimal function can return.

pub fn output_range(&self) -> usize

Returns output range of self, i.e. 1 + maximum value that self can return.

Source

impl Perfect<Bits8, SeedOnly, BuildDefaultSeededHasher>

pub fn from_vec_st<K>(keys: Vec<K>) -> Self
where K: Hash,

Constructs Perfect function for given keys, using a single thread.

keys cannot contain duplicates.

pub fn from_vec_mt<K>(keys: Vec<K>) -> Self
where K: Hash + Send + Sync,

Constructs Perfect function for given keys, using multiple threads.

keys cannot contain duplicates.

pub fn from_slice_st<K>(keys: &[K]) -> Self
where K: Hash + Clone,

Constructs Perfect function for given keys, using a single thread.

keys cannot contain duplicates.

pub fn from_slice_mt<K>(keys: &[K]) -> Self
where K: Hash + Clone + Send + Sync,

Constructs Perfect function for given keys, using multiple threads.

keys cannot contain duplicates.

Source

impl Perfect<Bits8, SeedOnlyK, BuildDefaultSeededHasher>

pub fn k_from_vec_st<K>(k: u8, keys: Vec<K>) -> Self
where K: Hash,

Constructs k-Perfect function for given keys, using a single thread. k-Perfect function maps k or less different keys to each value.

keys cannot contain duplicates.

pub fn k_from_vec_mt<K>(k: u8, keys: Vec<K>) -> Self
where K: Hash + Send + Sync,

Constructs k-Perfect function for given keys, using multiple threads. k-Perfect function maps k or less different keys to each value.

keys cannot contain duplicates.

pub fn k_from_slice_st<K>(k: u8, keys: &[K]) -> Self
where K: Hash + Clone,

Constructs k-Perfect function for given keys, using a single thread. k-Perfect function maps k or less different keys to each value.

keys cannot contain duplicates.

pub fn k_from_slice_mt<K>(k: u8, keys: &[K]) -> Self
where K: Hash + Clone + Send + Sync,

Constructs k-Perfect function for given keys, using multiple threads. k-Perfect function maps k or less different keys to each value.

keys cannot contain duplicates.