pub struct SeedOnly;Expand description
SeedChooser to build (1-)perfect functions.
Can be used with any function type: [Function], [Function2], [Perfect].
It chooses best seed with quite strong hasher, without shift component, which should lead to small size, but long construction time.