pub struct ShiftOnlyWrapped<const MULTIPLIER: u8 = 1>;Expand description
SeedChooser to build (1-)perfect functions called PHast+ with wrapping.
Can be used with any function type: [Function], [Function2], [Perfect].
It chooses best seed using only shifting with wrapping, which leads to quite small size and quite fast construction.
MULTIPLIER should be 1, 2, or 3.
Typically, increasing MULTIPLIER reduces size but slows down construction.
MULTIPLIER=1 works very well with large bits_per_seed (10+),
larger values (2 and 3) works well with bits_per_seed=8.