ShiftSeedWrapped

Struct ShiftSeedWrapped 

pub struct ShiftSeedWrapped<const MULTIPLIER: u8>(pub u8);
SeedChooser to build (1-)perfect functions which uses both shifting with wrapping and regular hashing. The parameter points the number of bits of seed used for regular hashing. Increasing it reduces size but slows down construction.

Can be used with any function type: [Function], [Function2], [Perfect].

It chooses best seed using both shifting with wrapping and hashing, which leads to small size and medium speed constrictions, but quite slow evaluation.

MULTIPLIER should be 1, 2, or 3. Typically, increasing MULTIPLIER reduces size but slows down construction.

Tuple Fields

0: u8