pub struct BitsFast(pub u8);Expand description
Size in bits.
Uses unaligned reads/writes to access data in SeedSize implementation.
Tuple Fields
0: u8Trait Implementations
Sourceimpl SeedSize for BitsFast
impl SeedSize for BitsFast
type VecElement = u8
fn new_zeroed_seed_vec(&self, number_of_seeds: usize) -> Box<[Self::VecElement]>
fn new_seed_vec( &self, seed: u16, number_of_seeds: usize, ) -> Box<[Self::VecElement]>
Sourceunsafe fn get_seed(&self, vec: &[Self::VecElement], index: usize) -> u16
unsafe fn get_seed(&self, vec: &[Self::VecElement], index: usize) -> u16
Gets seed with given
index from vec.
Does not check whether the index is within bounds.Sourceunsafe fn set_seed(&self, vec: &mut [Self::VecElement], index: usize, seed: u16)
unsafe fn set_seed(&self, vec: &mut [Self::VecElement], index: usize, seed: u16)
Sets seed with given
index in vec to seed.
Does not check whether the index is within bounds.Sourceunsafe fn init_seed(
&self,
vec: &mut [Self::VecElement],
index: usize,
seed: u16,
)
unsafe fn init_seed( &self, vec: &mut [Self::VecElement], index: usize, seed: u16, )
Sets seed with given
index in zeroed vec to seed.
Does not check whether the index is within bounds and vec is zeroed.fn write_seed_vec( &self, output: &mut dyn Write, seeds: &[Self::VecElement], ) -> Result<()>
fn read_seed_vec( input: &mut dyn Read, number_of_seeds: usize, ) -> Result<(Self, Box<[Self::VecElement]>)>
const VEC_ELEMENT_BIT_SIZE: usize = _
fn validate(&self) -> Result<Self, &'static str>
fn concatenate_seed_vecs<LSI, LS>( &self, level_sizes: LS, seeds: Vec<Box<[Self::VecElement]>>, ) -> Box<[Self::VecElement]>
impl Copy for BitsFast