pub struct Partial<SS, SC = SeedOnly, S = RandomState>where
SS: SeedSize,{ /* private fields */ }Expand description
Map-or-bump function that assigns different numbers to some keys and None to other.
Can be used with any seed chooser (which specify a particular PHast variant):
[ShiftOnlyWrapped], [ShiftSeedWrapped], SeedOnly, [SeedOnlyK].
See: Piotr Beling, Peter Sanders, PHast - Perfect Hashing made fast, 2025, https://arxiv.org/abs/2504.17918
Implementations
Sourceimpl<SS: SeedSize, SC: SeedChooser> Partial<SS, SC, ()>
impl<SS: SeedSize, SC: SeedChooser> Partial<SS, SC, ()>
pub fn with_hashes_bps_conf_sc_be_u<'k, BE>(
hashes: &'k mut [u64],
seed_size: SS,
conf: Conf,
seed_chooser: SC,
bucket_evaluator: BE,
) -> (Self, usize)where
BE: BucketToActivateEvaluator,
pub fn with_hashes_bps_conf_bs_threads_sc_be_u<'k, BE>( hashes: &'k mut [u64], seed_size: SS, conf: Conf, threads_num: usize, seed_chooser: SC, bucket_evaluator: BE, ) -> (Self, usize)
pub fn with_hashes_bps_conf_sc_be<'k, BE>(
hashes: &'k mut [u64],
seed_size: SS,
conf: Conf,
seed_chooser: SC,
bucket_evaluator: BE,
) -> Selfwhere
BE: BucketToActivateEvaluator,
pub fn with_hashes_bps_conf_bs_threads_sc_be<'k, BE>( hashes: &'k mut [u64], seed_size: SS, conf: Conf, threads_num: usize, seed_chooser: SC, bucket_evaluator: BE, ) -> Self
pub fn with_hashes_p_sc_be_u<'k, BE>(
hashes: &'k mut [u64],
params: &Params<SS>,
seed_chooser: SC,
bucket_evaluator: BE,
) -> (Self, usize)where
BE: BucketToActivateEvaluator,
pub fn with_hashes_p_threads_sc_be_u<'k, BE>( hashes: &'k mut [u64], params: &Params<SS>, threads_num: usize, seed_chooser: SC, bucket_evaluator: BE, ) -> (Self, usize)
pub fn with_hashes_p_sc_be<'k, BE>(
hashes: &'k mut [u64],
params: &Params<SS>,
seed_chooser: SC,
bucket_evaluator: BE,
) -> Selfwhere
BE: BucketToActivateEvaluator,
pub fn with_hashes_p_threads_sc_be<'k, BE>( hashes: &'k mut [u64], params: &Params<SS>, threads_num: usize, seed_chooser: SC, bucket_evaluator: BE, ) -> Self
pub fn with_hashes_p_sc_u<'k, BE>(
hashes: &'k mut [u64],
params: &Params<SS>,
seed_chooser: SC,
) -> (Self, usize)where
BE: BucketToActivateEvaluator,
pub fn with_hashes_p_threads_sc_u<'k, BE>( hashes: &'k mut [u64], params: &Params<SS>, threads_num: usize, seed_chooser: SC, ) -> (Self, usize)
pub fn with_hashes_p_sc<'k>( hashes: &'k mut [u64], params: &Params<SS>, seed_chooser: SC, ) -> Self
pub fn with_hashes_p_threads_sc<'k>(
hashes: &'k mut [u64],
params: &Params<SS>,
threads_num: usize,
seed_chooser: SC,
) -> Selfwhere
SC: Sync,
Sourceimpl<SS: SeedSize, SC: SeedChooser, S> Partial<SS, SC, S>
impl<SS: SeedSize, SC: SeedChooser, S> Partial<SS, SC, S>
Sourcepub fn get_for_hash(&self, key_hash: u64) -> Option<usize>
pub fn get_for_hash(&self, key_hash: u64) -> Option<usize>
Returns value assigned to the given key hash or None.
Sourceimpl<SS: SeedSize, SC: SeedChooser, S> Partial<SS, SC, S>
impl<SS: SeedSize, SC: SeedChooser, S> Partial<SS, SC, S>
Sourcepub fn minimal_output_range(&self, num_of_keys: u32) -> usize
pub fn minimal_output_range(&self, num_of_keys: u32) -> usize
Returns output range of minimal (perfect or k-perfect) function for given number of keys, i.e. 1 + maximum value that minimal function can return.
Sourcepub fn output_range(&self) -> usize
pub fn output_range(&self) -> usize
Returns output range of self, i.e. 1 + maximum value that self can return.
Sourceimpl<SS: SeedSize, SC: SeedChooser, S: BuildHasher> Partial<SS, SC, S>
impl<SS: SeedSize, SC: SeedChooser, S: BuildHasher> Partial<SS, SC, S>
Sourcepub fn get<K>(&self, key: &K) -> Option<usize>
pub fn get<K>(&self, key: &K) -> Option<usize>
Returns value assigned to the given key or None.
The returned value is in the range from 0 (inclusive) to the number of elements in the input key collection (exclusive).
key must come from the input key collection given during construction.
Sourcepub fn with_keys_p_hash_sc_be_u<'k, K, BE>(
keys: impl Iterator<Item = K>,
params: &Params<SS>,
hasher: S,
seed_chooser: SC,
bucket_evaluator: BE,
) -> (Self, usize)where
K: Hash,
BE: BucketToActivateEvaluator,
pub fn with_keys_p_hash_sc_be_u<'k, K, BE>(
keys: impl Iterator<Item = K>,
params: &Params<SS>,
hasher: S,
seed_chooser: SC,
bucket_evaluator: BE,
) -> (Self, usize)where
K: Hash,
BE: BucketToActivateEvaluator,
Returns Partial function and number of keys with unassigned values for given keys,
using a single thread and given parameters.