pub struct ShiftSeedWrapped<const MULTIPLIER: u8>(pub u8);Expand description
SeedChooser to build (1-)perfect functions which uses both shifting with wrapping and regular hashing.
The parameter points the number of bits of seed used for regular hashing.
Increasing it reduces size but slows down construction.
Can be used with any function type: [Function], [Function2], [Perfect].
It chooses best seed using both shifting with wrapping and hashing, which leads to small size and medium speed constrictions, but quite slow evaluation.
MULTIPLIER should be 1, 2, or 3.
Typically, increasing MULTIPLIER reduces size but slows down construction.
Tuple Fields
0: u8Trait Implementations
Sourceimpl<const MULTIPLIER: u8> Clone for ShiftSeedWrapped<MULTIPLIER>
impl<const MULTIPLIER: u8> Clone for ShiftSeedWrapped<MULTIPLIER>
Sourcefn clone(&self) -> ShiftSeedWrapped<MULTIPLIER>
fn clone(&self) -> ShiftSeedWrapped<MULTIPLIER>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<const MULTIPLIER: u8> SeedChooser for ShiftSeedWrapped<MULTIPLIER>
impl<const MULTIPLIER: u8> SeedChooser for ShiftSeedWrapped<MULTIPLIER>
type UsedValues = CyclicSet<{MAX_VALUES/64}>
fn conf( self, output_range: usize, input_size: usize, bits_per_seed: u8, bucket_size_100: u16, preferred_slice_len: u16, ) -> Conf
Sourcefn f(self, primary_code: u64, seed: u16, conf: &Conf) -> usize
fn f(self, primary_code: u64, seed: u16, conf: &Conf) -> usize
Returns function value for given primary code and seed.
Sourcefn best_seed(
self,
used_values: &mut Self::UsedValues,
keys: &[u64],
conf: &Conf,
bits_per_seed: u8,
) -> u16
fn best_seed( self, used_values: &mut Self::UsedValues, keys: &[u64], conf: &Conf, bits_per_seed: u8, ) -> u16
Returns best seed to store in seeds array or
u16::MAX if NO_BUMPING is true and there is no feasible seed.Sourceconst FIRST_SEED: u16 = _
const FIRST_SEED: u16 = _
The lowest seed that does not indicate bumping.
Sourceconst FUNCTION2_THRESHOLD: usize = 4096
const FUNCTION2_THRESHOLD: usize = 4096
Size of last level of Function2. Important when
extra_shift()>0 (i.e. for ShiftOnly).Sourcefn k(self) -> u8
fn k(self) -> u8
Returns maximum number of keys mapped to each output value;
k of k-perfect function.Sourcefn minimal_output_range(self, num_of_keys: usize) -> usize
fn minimal_output_range(self, num_of_keys: usize) -> usize
Returns output range of minimal (perfect or k-perfect) function for given number of keys.
fn bucket_evaluator(&self, bits_per_seed: u8, slice_len: u16) -> Weights
fn conf_for_minimal( self, num_of_keys: usize, bits_per_seed: u8, bucket_size_100: u16, preferred_slice_len: u16, ) -> Conf
fn conf_for_minimal_p<SS: Copy + Into<u8>>( self, num_of_keys: usize, params: &Params<SS>, ) -> Conf
Sourcefn extra_shift(self, _bits_per_seed: u8) -> u16
fn extra_shift(self, _bits_per_seed: u8) -> u16
How much the chooser can add to value over slice length.
impl<const MULTIPLIER: u8> Copy for ShiftSeedWrapped<MULTIPLIER>